import os
import config
import getpass

def check_account():
    while True:
        username = input('What is your username? ')
        #Checks username.txt for user's inputted username
        with open('username.txt', 'r') as searchUsername:
            textFileSearch = searchUsername.readlines()
            for row in textFileSearch:
                findUserName = row.find(username)
                if findUserName == 0:
                    print('\nWelcome back, {}.'.format(username))
                    global workingFolder
                    workingFolder = r'/Users/' + getpass.getuser() + r'/Documents/Flashcards Program/Users/' + username
                    config.workingFolder = workingFolder
                    #return instead of break - return ends function rather than just breaking loop
                    return

        #this code will only run if the user inputted username was not found
        print('\n{} is not a registered username.\n'.format(username))
        loopBreak = input('Are you sure you have an account? If you do not have an account, type \'create account.\' ')
        if loopBreak.lower() == 'create account':
            create_account()

def create_account():
  while True:
    username = input('\nCreate a username for your account. If you already have an account, type \'have account\': ')
    if username.lower() == 'have account':
        check_account()
        return

    try:
        if username == '\'\'' or username == '\"\"':
            raise Exception('Cannot use {} as a username'.format(username))

        newPath = os.path.join(r'/Users/' + getpass.getuser() + r'/Documents/Flashcards Program/Users/' + username)
        os.makedirs(newPath)

        with open('username.txt', 'a') as usernameHolder:
            usernameHolder.write(username + '\n')
        print('\nYour account has successfully been created. You are currently logged in as: {}\n'.format(username))
        config.workingFolder = newPath
        break
    except Exception:
        print('\nCannot use {} as a username. Please try a different one. '.format(username))
    except:
        print('This user has already been created. Please try another username.')

def main():
    if config.error_control('yes','no', '\nDo you have an account? (Enter Yes or No) ') == True:
        check_account()
    else:
        create_account()
  #User account is confirmed by this point. 'Welcome back user' message pops up

if __name__ == "__main__":
    main()


import accountlogin
import studyoptions
import setcreation as sc
import deletion
import config as cg

def menu_input():
  option = -1
  while True:
    option = input('\nEnter 1-7: ')
    try:
      if 1 <= int(option) <= 7:
        break
      else:
        print('Error: Please enter a number 1-7')
    except:
      print('Error: Please enter a number 1-7')
  return option

def main():
  print('\n---------------------------------------------- Welcome to the Flashcards Study App ----------------------------------------------')
  print('This app allows you to create study sets in app and import study sets from both .CSV files and Quizlet sets.')
  print('You also have multiple study options: Flashcards and Self-Testing. Within both options, you can choose if flashcards are ')
  print('presented in their inputted order or a random order. You also have a choice to see the term or definition first.')
  print('To use this app, you will need to have an account. You can also delete your study sets or your account at any time.')
  input('To find your created study sets, locate them in your documents folder. Press enter when you are ready to create/log into an account.')
  
  #Logs in current user - creates account if necessary. 
  accountlogin.main()

  run_loop = True
  while run_loop:
    studysetCheck = sc.study_set_check('current')

    print('\nYou have seven possible actions:')
    print('1. Create and save a flashcard set')
    print('2. Import a Quizlet')
    print('3. Import a CSV file located in your desktop')
    print('4. Study from a created set')
    print('5. Delete a Study Set')
    print('6. Delete your account')
    print('7. End the program')

    option = int(menu_input())
    if option == 1:
      studysetCheck = True
      sc.create_and_save_studyset()
    elif option == 2:
      studysetCheck = True
      sc.import_quizlet()
    elif option == 3:
      studysetCheck = True
      sc.import_csv()
    elif option == 4:
      if studysetCheck == False:
        print('\nYou cannot study from a study set since you do not have any. Please create or import a study set.\n')
      else:
        sc.study_set_check('current')
        studyoptions.main()
    elif option == 5:
      if studysetCheck != False:
        studysetCheck = sc.study_set_check('current')
        while (studysetCheck != False):
          studysetCheck = deletion.set_deletion()
          break
      else:
        print('\nYou cannot delete any study sets as you do not have any. Please select a different option.\n')
    elif option == 6:
      if cg.error_control('yes', 'no', '\nAre you sure you want to delete your account? You cannot reverse this. Enter Yes or No. ') == True:
        deletion.user_deletion()
        print('\nPROGRAM ENDED\n')
        return
    elif option == 7:
      run_loop = False
  print('\nPROGRAM ENDED\n')

main()


import os
import config
import getpass
from setcreation import study_set_check

def set_deletion():
  while True:
    deleteSet = input('\nWhich set would you like to delete? If you would not like to delete a set, type \'No\': ')
    if deleteSet.lower() == 'no':
      break
    deleteSet += '.txt'

    #Deletes set and confirms it
    allFiles = os.listdir(config.workingFolder)
    for file in allFiles:
        line = config.workingFolder + r'/' + file
        if file == deleteSet:
            os.remove(line)
            allFiles.remove(file)
            print('\n{} was successfully deleted.'.format(file.rsplit('.', 1)[0]))
            break
    else:
        print('File {} does not exist. Please try deleting an existing file.'.format(deleteSet.rsplit('.', 1)[0]))
        set_deletion()

    if study_set_check('remaining') == False:
        return False
    if config.error_control('yes', 'no', '\nWould you like to delete another file? Enter Yes or No. ') != True:
        break

def user_deletion():
  #Removes all files in directory, then user folder
  for file in os.listdir(config.workingFolder):
    os.remove(config.workingFolder + r'/' + file)
  os.rmdir(config.workingFolder)
  
  #Rewrites username.txt file without user who is being deleted
  with open('username.txt', 'r') as textFile:
    usernameList = textFile.readlines()
  with open('username.txt', 'w') as usernameFile:
    for username in usernameList:
      if (config.workingFolder + '\n') == ((r'/Users/' + getpass.getuser() + r'/Documents/Flashcards Program/Users/') + username):
        pass
      else:
        usernameFile.write(username)

  print('\nACCOUNT DELETED')


import os
import random
import config

def study_from_created_set():
  while True:
    flashOrTest = config.error_control('f', 't', 'To study flashcard style, type \'F\'. To test yourself, type \'T\': ')
    orderOrRandom = config.error_control('o', 'r', '\nWould you like the flashcards to presented in order (\'O\') or randomly (\'R\')? ')
    if flashOrTest == True:
      termOrDef = config.error_control('t', 'd', 'Would you like the term first (\'T\') or definition first (\'D\')? ')
    elif flashOrTest == False:
      termOrDef = config.error_control('t', 'd', 'Would you like to input the term (\'T\') or the definition (\'D\')? ')
    
    with open(config.workingFolder + r'/' + workingSet, 'r') as file:
      lineList = file.readlines()
      lenLineList = len(lineList)

      for indece in range(0, lenLineList):
        if orderOrRandom == True:
          tempFlashcard = lineList[indece]
        elif orderOrRandom == False:
          tempFlashcard = random.choice(lineList)
          lineList.remove(tempFlashcard)
        tempFlashcard = tempFlashcard.rstrip('\n').split(chr(0x2588))

        term = tempFlashcard[0]
        definition = tempFlashcard[1]

        if termOrDef == True:
          outputFormat = {'choice1':'term', 'choice2':'definition', 'var1':term,'var2':definition}
        elif termOrDef == False:
          outputFormat = {'choice1':'definition', 'choice2':'term', 'var1':definition,'var2':term}

        if flashOrTest  == True:
          flashcard_style(outputFormat, indece, lenLineList)
        elif flashOrTest == False:
          test_yourself(outputFormat, indece)
    
    if config.error_control('yes', 'no', '\nWould you like to study this set again? (Enter Yes or No) ') != True:
      break

def flashcard_style(outputFormat, indece, lenLineList):
  print(('\n{} {}: {}').format(outputFormat['choice1'], str(indece+1), outputFormat['var1']))
  input('\nPress enter when you are ready for the {}: '.format(outputFormat['choice2']))
  print(('\n{} {}: {}').format(outputFormat['choice2'], str(indece+1), outputFormat['var2']))
  if (indece+1) < lenLineList:
    input('\nPress enter when you are ready for the next {}: '.format(outputFormat['choice1']))

def test_yourself(outputFormat, indece):
  guessAgain = 'y'
  while guessAgain == 'y':
    print(('\n{} {}: {}').format(outputFormat['choice2'], str(indece+1), outputFormat['var2']))
    guess = input(('Type in the correct {} for {} {}: ').format(outputFormat['choice1'], outputFormat['choice2'], str(indece+1)))
    if guess == outputFormat['var1'].strip():
      input('You got the {} right! Press enter to continue.'.format(outputFormat['choice2']))
      break
    guessAgain = input('Your guess did not match the correct {}. Would you like to try again? '.format(outputFormat['choice1']))
    if guessAgain[0].lower() == 'y':
      guessAgain = 'y'
    else:
      input(('The correct {} to {} {} is {}. Press enter to continue').format(outputFormat['choice2'], outputFormat['choice1'], str(indece+1), outputFormat['var1']))

def main():
  while True:
    choiceList = os.listdir(config.workingFolder)
    setChoice = input('\nWhich study set would you like to study from? If you would not like to study from a created set, enter \'No\' ')
    if setChoice.lower() == 'no':
      return

    for choice in choiceList:
      if choice == (setChoice + '.txt'):
        global workingSet
        workingSet = choice
        study_from_created_set()
        return
    else:
      print('That study set does not exist. Please try again. ')

if __name__ == '__main__':
  main()


import os
import csv
import getpass
import config

#Checks for study sets; returns created study sets
def study_set_check(outputControl):
  fileList = []
  counter = 0
  for file in os.listdir(config.workingFolder):
    if not file.endswith('.DS_Store'):
      counter += 1
      fileList.append(file)

  if counter == 1:
    print('Your only set is: {}'.format(fileList[0].rsplit('.', 1)[0]))
  elif counter > 1:
    print('\nThese are your {} study sets:'.format(outputControl))
    for file in fileList:
        print('You have a set called: {}'.format(file.rsplit('.', 1)[0]))
  else:
    print('You do not have any flashcard sets.\n')
    return False

#Gets name of flashcard set; allows user to exit set creation; checks to see if user-chosen file name already exists
def set_creation_check():
  while True:
    userInput = input('What would you like to name your flashcard set? If you would not like to create a set, type \'No\' ')
    if userInput.lower() == 'no':
      return False
    else:
      for file in os.listdir(config.workingFolder):
        if (file == userInput + '.txt' or file == userInput):
          print('A file with this name already exists. Please try using a different file name.\n')
          break
      else:
        return userInput

#Formats output
def set_creation_output(term, definition, flashcards, output1, output2, output3):
  if (term == '' or definition == ''):
    print(output1)
    return False, False
  elif term.lower() == 'no':
    print(output2)
    return False, False
  elif term in flashcards:
    print(output3)
    return False, False
  else:
    return term, definition

#Writes flashcard .txt file
def write_file(filepath, flashcards):
  with open(filepath, 'a') as termsAndDef: 
    for key, value in flashcards.items(): 
      termsAndDef.write('{}{}{}\n'.format(key, chr(0x2588), value))

#Creating study set through app
def create_and_save_studyset():
  userInput = set_creation_check()
  if userInput == False:
    return

  print('\nYou need at least 5 Term/Definition pairs to create a functional flashcards set.')

  flashcards = {}
  while True:
    while len(flashcards) < 5:
      term, definition = set_creation_output(input("\nEnter term: "), input("Enter definition: "), flashcards,
        'You cannot enter a blank term or definition. Please try again.',
        'You cannot have a term named \'No\'. Please enter a differently named term',
        'This term is a repeat. Please enter a different term.')
      if term != False:
        flashcards[term] = definition
    if config.error_control('yes', 'no', '\nWould you like to add another flashcard? (Enter Yes or No) ') != True:
      break
    
  write_file(os.path.join(config.workingFolder + r'/' + userInput + r'.txt'), flashcards)

#Importing Quizlet
def import_quizlet():
  print('\nTo import from Quizlet, follow these steps:\n')
  print('1. Go to the set which you want to export on Quizlet, and make sure you do not have any terms/definitions which span multiple lines.')
  print('2. Then, scroll down to find the three dots. (Located between the large flashcard and individual terms, near the top)')
  print('3. Click on the three dots, then click export')
  print('4. Select \'Other\' for the \'Between term and definition\' section, and put two dashes (--). Then, select \'New Line\' for the \'Between rows\' section.')
  print('5. Optionally check of \'Alphabetize section\'')
  print('6. Press copy text. Once you have copied your text, name your set and paste it')
  print('7. When you have imported your set, press enter twice.\n')
  
  userInput = set_creation_check()
  if userInput == False:
    return
    
  #Captures pasted study sets
  setList = input('Input here: ')
  text = []
  while True:
    setList = input('')
    if setList == '':
      break
    text.append(setList)

  counter = 0
  flashcards = {}
  for list in text:
    counter += 1
    tempList = list.split('--')

    term, definition = set_creation_output(tempList[0], tempList[1], flashcards,
      '\nThere is an empty term/def in row {}. Empty spaces are not allowed. This row has not been added to your study set.'.format(counter),
      '\nThere is a term named \'No\' in row {}. Terms cannot be named \'No\'. This row has not been added to your study set.'.format(counter),
      '\nThe term in row {} is a repeat. Terms cannot be repeated. This row has not been added to your study set.'.format(counter))

    if term!= False:
      flashcards[term] = definition
        
  write_file(os.path.join(config.workingFolder + r'/' + userInput + r'.txt'), flashcards)

#importing CSV
def import_csv():
  userInput = set_creation_check()
  if userInput == False:
    return

  while True:
    print('\nTo import a .CSV file:')
    print('1. Make sure your file has two columns: the leftwards one containing terms and the rightwards one containing definitions.')
    print('2. Make sure you have at least 5 valid Term/Definition pairs to function as a study set.')
    print('3. Remember to include the full name of the file, including the .CSV extension.\n')

    fileName = input('What is the full name of the .csv file you are importing? ')
    desktopFiles = os.listdir(r'/Users/' + getpass.getuser() + r'/Desktop/')
    for file in desktopFiles:
      if fileName == file:
        break
    if fileName == file:
      break
    print('CSV file {} does not exist. Please try another file name.\n'.format(fileName))

  #this only checks desktop - when building GUI, add 'dropbox' option
  with open(r'/Users/' + getpass.getuser() + r'/Desktop/' + fileName, 'r') as file:
    reader = csv.reader(file)

    flashcards = {}
    counter = -1
    for row in reader:
      counter += 1
      term, definition = set_creation_output(row[0], row[1], flashcards,
        '\nThere is an empty term/def in row {}. Empty spaces are not allowed. This row has not been added to your study set.'.format(counter),
        '\nThere is a term named \'No\' in row {}. Terms cannot be named \'No\'. This row has not been added to your study set.'.format(counter),
        '\nThe term in row {} is a repeat. Terms cannot be repeated. This row has not been added to your study set.'.format(counter))
            
      if term != False:
        flashcards[term] = definition

  if len(flashcards) < 5:
    print('\nYou cannot have a flashcards set with less than 5 terms. Please try a different .CSV file.')
  else:
    write_file(os.path.join(config.workingFolder + r'/' + userInput + r'.txt'), flashcards)
    print('\nSET CREATED\n')


from setuptools import setup, find_packages

VERSION = '0.0.1'
DESCRIPTION = 'Flashcards Study App'

# Setting up
setup(
    name="Flashcards Terminal App",
    version=VERSION,
    author="jasonl27 (Jason Layvand)",
    author_email="<jasonlayvand@gmail.com>",
    description=DESCRIPTION,
    packages=find_packages(),
    install_requires=['os', 'getpass', 'csv', 'random'],
    keywords=['python', 'terminal', 'app', 'study'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: MacOS :: MacOS X",
    ]
)


workingFolder = ''

#Error Control Function - logic1 and logic2 are error control breakers
def error_control(logic1, logic2, text):
  errorControl = True
  while errorControl == True:
    userInput = input(text).lower()
    if userInput == logic1:
      return True
    elif userInput == logic2:
      return False
    else:
      print('Please answer {} or {}'.format(logic1, logic2))